BodyTrackingCalibrationStateMETA

Struct BodyTrackingCalibrationStateMETA 

pub struct BodyTrackingCalibrationStateMETA(/* private fields */);
Implementations

Source

impl BodyTrackingCalibrationStateMETA

pub const VALID: BodyTrackingCalibrationStateMETA

Valid calibration, body tracking expected to be stable.

pub const CALIBRATING: BodyTrackingCalibrationStateMETA

Calibration is in progress, body joint poses from XR_FB_body_tracking are valid to read and internally consistent within a single call, but may: be more variable than normal, shifting dramatically before calibration ends.

pub const INVALID: BodyTrackingCalibrationStateMETA

Calibration is invalid, accessing the body joint poses from XR_FB_body_tracking is defined behavior but their contents are unspecified. Tracking data may: be read but must: not be interpreted as body tracking poses.

pub fn from_raw(x: i32) -> Self

pub fn into_raw(self) -> i32