#[repr(transparent)]pub struct CompositionLayerSecureContentFlagsFB(_);Expand description
Implementations
sourceimpl CompositionLayerSecureContentFlagsFB
impl CompositionLayerSecureContentFlagsFB
sourcepub const EXCLUDE_LAYER: CompositionLayerSecureContentFlagsFB = _
pub const EXCLUDE_LAYER: CompositionLayerSecureContentFlagsFB = _
Indicates the layer will only be visible inside the HMD, and not visible to external sources
sourcepub const REPLACE_LAYER: CompositionLayerSecureContentFlagsFB = _
pub const REPLACE_LAYER: CompositionLayerSecureContentFlagsFB = _
Indicates the layer will be displayed inside the HMD, but replaced by proxy content when written to external sources
sourceimpl CompositionLayerSecureContentFlagsFB
impl CompositionLayerSecureContentFlagsFB
pub const EMPTY: Self = _
pub fn from_raw(x: u64) -> Self
pub fn into_raw(self) -> u64
pub fn is_empty(self) -> bool
pub fn intersects(self, other: CompositionLayerSecureContentFlagsFB) -> bool
sourcepub fn contains(self, other: CompositionLayerSecureContentFlagsFB) -> bool
pub fn contains(self, other: CompositionLayerSecureContentFlagsFB) -> bool
Returns whether other is a subset of self