Struct openxr_sys::InputSourceLocalizedNameFlags
source · [−]#[repr(transparent)]pub struct InputSourceLocalizedNameFlags(_);Expand description
Implementations
sourceimpl InputSourceLocalizedNameFlags
impl InputSourceLocalizedNameFlags
sourcepub const USER_PATH: InputSourceLocalizedNameFlags = _
pub const USER_PATH: InputSourceLocalizedNameFlags = _
Asks for the part of the string which indicates the top level user path the source represents
sourcepub const INTERACTION_PROFILE: InputSourceLocalizedNameFlags = _
pub const INTERACTION_PROFILE: InputSourceLocalizedNameFlags = _
Asks for the part of the string which represents the interaction profile of the source
sourcepub const COMPONENT: InputSourceLocalizedNameFlags = _
pub const COMPONENT: InputSourceLocalizedNameFlags = _
Asks for the part of the string which represents the component on the device which needs to be interacted with
sourceimpl InputSourceLocalizedNameFlags
impl InputSourceLocalizedNameFlags
pub const EMPTY: Self = _
pub fn from_raw(x: u64) -> Self
pub fn into_raw(self) -> u64
pub fn is_empty(self) -> bool
pub fn intersects(self, other: InputSourceLocalizedNameFlags) -> bool
sourcepub fn contains(self, other: InputSourceLocalizedNameFlags) -> bool
pub fn contains(self, other: InputSourceLocalizedNameFlags) -> bool
Returns whether other is a subset of self