Struct openxr_sys::PerfSettingsLevelEXT
source · [−]#[repr(transparent)]pub struct PerfSettingsLevelEXT(_);Expand description
Implementations
sourceimpl PerfSettingsLevelEXT
impl PerfSettingsLevelEXT
sourcepub const POWER_SAVINGS: PerfSettingsLevelEXT = _
pub const POWER_SAVINGS: PerfSettingsLevelEXT = _
Performance settings hint used by the application to indicate that it enters a non-XR section (head-locked / static screen), during which power savings are to be prioritized
sourcepub const SUSTAINED_LOW: PerfSettingsLevelEXT = _
pub const SUSTAINED_LOW: PerfSettingsLevelEXT = _
Performance settings hint used by the application to indicate that it enters a low and stable complexity section, during which reducing power is more important than occasional late rendering frames
sourcepub const SUSTAINED_HIGH: PerfSettingsLevelEXT = _
pub const SUSTAINED_HIGH: PerfSettingsLevelEXT = _
Performance settings hint used by the application to indicate that it enters a high or dynamic complexity section, during which the XR Runtime strives for consistent XR compositing and frame rendering within a thermally sustainable range
sourcepub const BOOST: PerfSettingsLevelEXT = _
pub const BOOST: PerfSettingsLevelEXT = _
Performance settings hint used by the application to indicate that the application enters a section with very high complexity, during which the XR Runtime is allowed to step up beyond the thermally sustainable range
pub fn from_raw(x: i32) -> Self
pub fn into_raw(self) -> i32