#[repr(transparent)]
pub struct PerfSettingsNotificationLevelEXT(_);
Implementations

Notifies that the sub-domain has reached a level where no further actions other than currently applied are necessary

Notifies that the sub-domain has reached an early warning level where the application should start proactive mitigation actions with the goal to return to the XR_PERF_NOTIF_LEVEL_NORMAL level

Notifies that the sub-domain has reached a critical level with significant performance degradation. The application should take drastic mitigation action