Struct openxr_sys::PerfSettingsSubDomainEXT
source · [−]#[repr(transparent)]pub struct PerfSettingsSubDomainEXT(_);Expand description
Implementations
sourceimpl PerfSettingsSubDomainEXT
impl PerfSettingsSubDomainEXT
sourcepub const COMPOSITING: PerfSettingsSubDomainEXT = _
pub const COMPOSITING: PerfSettingsSubDomainEXT = _
Indicates that the performance notification originates from the COMPOSITING sub-domain
sourcepub const RENDERING: PerfSettingsSubDomainEXT = _
pub const RENDERING: PerfSettingsSubDomainEXT = _
Indicates that the performance notification originates from the RENDERING sub-domain
sourcepub const THERMAL: PerfSettingsSubDomainEXT = _
pub const THERMAL: PerfSettingsSubDomainEXT = _
Indicates that the performance notification originates from the THERMAL sub-domain
pub fn from_raw(x: i32) -> Self
pub fn into_raw(self) -> i32