#[repr(transparent)]
pub struct Result(_);
Error and return codes - see XrResult

Implementations

Function successfully completed.

The specified timeout time occurred before the operation could complete.

The session will be lost soon.

No event was available.

The space’s bounds are not known at the moment.

The session is not in the focused state.

A frame has been discarded from composition.

The function usage was invalid in some way.

The runtime failed to handle the function in an unexpected way that is not covered by another error result.

A memory allocation has failed.

The runtime does not support the requested API version.

Initialization of object could not be completed.

The requested function was not found or is otherwise unsupported.

The requested feature is not supported.

A requested extension is not supported.

The runtime supports no more of the requested resource.

The supplied size was smaller than required.

A supplied object handle was invalid.

The XrInstance was lost or could not be found. It will need to be destroyed and optionally recreated.

The session is already running.

The session is not yet running.

The XrSession was lost. It will need to be destroyed and optionally recreated.

The provided XrSystemId was invalid.

The provided XrPath was not valid.

The maximum number of supported semantic paths has been reached.

The semantic path character format is invalid.

The semantic path is unsupported.

The layer was NULL or otherwise invalid.

The number of specified layers is greater than the supported number.

The image rect was negatively sized or otherwise invalid.

The image format is not supported by the runtime or platform.

The API used to retrieve an action’s state does not match the action’s type.

The session is not in the ready state.

The session is not in the stopping state.

The provided XrTime was zero, negative, or out of range.

The specified reference space is not supported by the runtime or system.

The file could not be accessed.

The file’s contents were invalid.

The specified form factor is not supported by the current runtime or platform.

The specified form factor is supported, but the device is currently not available, e.g. not plugged in or powered off.

A requested API layer is not present or could not be loaded.

The call was made without having made a previously required call.

The given graphics device is not in a valid state. The graphics device could be lost or initialized without meeting graphics requirements.

The supplied pose was invalid with respect to the requirements.

The supplied index was outside the range of valid indices.

The specified view configuration type is not supported by the runtime or platform.

The specified environment blend mode is not supported by the runtime or platform.

The name provided was a duplicate of an already-existing resource.

The name provided was invalid.

A referenced action set is not attached to the session.

The session already has attached action sets.

The localized name provided was a duplicate of an already-existing resource.

The localized name provided was invalid.

The xrGetGraphicsRequirements* call was not made before calling xrCreateSession.

The loader was unable to find or load a runtime.

xrSetAndroidApplicationThreadKHR failed as thread id is invalid.

xrSetAndroidApplicationThreadKHR failed setting the thread attributes/priority.

Spatial anchor could not be created at that location.

The secondary view configuration was not enabled when creating the session.

The controller model key is invalid.

The reprojection mode is not supported.

Compute new scene not completed.

Scene component id invalid.

Scene component type mismatch.

Scene mesh buffer id invalid.

Scene compute feature incompatible.

Scene compute consistency mismatch.

The display refresh rate is not supported by the platform.

The color space is not supported by the runtime.

The component type is not supported for this space.

The required component is not enabled for this space.

A request to set the component’s status is currently pending.

The component is already set to the requested value.

The object state is unexpected for the issued command.

Trying to create an MR feature when one was already created and only one instance is allowed.

Requested functionality requires a feature to be created first.

Requested functionality is not permitted - application is not allowed to perform the requested operation.

There weren’t sufficient resources available to perform an operation.

Unknown Passthrough error (no further details provided).

The model key is invalid.

The model is unavailable.

Marker tracking is disabled or the specified marker is not currently tracked.

The specified marker ID is not valid.

A spatial anchor was not found associated with the spatial anchor name provided

The spatial anchor name provided was not valid