SemanticLabelBD

Struct SemanticLabelBD 

pub struct SemanticLabelBD(/* private fields */);
Implementations

Source

impl SemanticLabelBD

pub const UNKNOWN: SemanticLabelBD

Semantic label that the runtime does not know.

pub const FLOOR: SemanticLabelBD

Semantic label of floor.

pub const CEILING: SemanticLabelBD

Semantic label of ceiling.

pub const WALL: SemanticLabelBD

Semantic label of wall.

pub const DOOR: SemanticLabelBD

Semantic label of door.

pub const WINDOW: SemanticLabelBD

Semantic label of window.

pub const OPENING: SemanticLabelBD

Semantic label of opening, usually refers to a space that something or someone can pass through.

pub const TABLE: SemanticLabelBD

Semantic label of table.

pub const SOFA: SemanticLabelBD

Semantic label of sofa, usually refers to a seat that multiple people can sit on.

pub const CHAIR: SemanticLabelBD

Semantic label of chair, usually refers to a seat that for one person.

pub const HUMAN: SemanticLabelBD

Semantic label of human.

pub const BEAM: SemanticLabelBD

Semantic label of beam, which usually supports weight in a building or other structure.

pub const COLUMN: SemanticLabelBD

Semantic label of column, which is vertical and used as a support for the roof of a building.

pub const CURTAIN: SemanticLabelBD

Semantic label of curtain.

pub const CABINET: SemanticLabelBD

Semantic label of cabinet.

pub const BED: SemanticLabelBD

Semantic label of bed.

pub const PLANT: SemanticLabelBD

Semantic label of plant.

pub const SCREEN: SemanticLabelBD

Semantic label of screen.

pub const VIRTUAL_WALL: SemanticLabelBD

Semantic label of virtual wall, which is generated by the system scene capture app in order to create a closed space for users.

pub const REFRIGERATOR: SemanticLabelBD

Semantic label of refrigerator.

pub const WASHING_MACHINE: SemanticLabelBD

Semantic label of washing machine.

pub const AIR_CONDITIONER: SemanticLabelBD

Semantic label of air conditioner.

pub const LAMP: SemanticLabelBD

Semantic label of lamp.

pub const WALL_ART: SemanticLabelBD

Semantic label of wall art, like a painting or a photo frame.

pub const STAIRWAY: SemanticLabelBD

Semantic label of stairway.

pub fn from_raw(x: i32) -> Self

pub fn into_raw(self) -> i32