SemanticLabelsSupportFlagsFB

Struct SemanticLabelsSupportFlagsFB 

pub struct SemanticLabelsSupportFlagsFB(/* private fields */);
Implementations

Source

impl SemanticLabelsSupportFlagsFB

pub const MULTIPLE_SEMANTIC_LABELS: SemanticLabelsSupportFlagsFB

If set, and the runtime reports the extensionVersion as 2 or greater, the runtime may: return multiple semantic labels separated by a comma without spaces. Otherwise, the runtime must: return a single semantic label.

pub const ACCEPT_DESK_TO_TABLE_MIGRATION: SemanticLabelsSupportFlagsFB

If set, and the runtime reports the extensionVersion as 3 or greater, the runtime must: return “TABLE” instead of “DESK” as a semantic label to the application. Otherwise, the runtime must: return “DESK” instead of “TABLE” as a semantic label to the application, when applicable.

pub const ACCEPT_INVISIBLE_WALL_FACE: SemanticLabelsSupportFlagsFB

If set, and the runtime reports the extensionVersion as 4 or greater, the runtime may: return “INVISIBLE_WALL_FACE” instead of “WALL_FACE” as a semantic label to the application in order to represent an invisible wall used to conceptually separate a space (e.g., separate a living space from a kitchen space in an open floor plan house even though there is no real wall between the two spaces) instead of a real wall. Otherwise, the runtime must: return “WALL_FACE” as a semantic label to the application in order to represent both an invisible and real wall, when applicable.

Source

impl SemanticLabelsSupportFlagsFB

pub const EMPTY: Self

pub fn from_raw(x: u64) -> Self

pub fn into_raw(self) -> u64

pub fn is_empty(self) -> bool

pub fn intersects(self, other: SemanticLabelsSupportFlagsFB) -> bool

pub fn contains(self, other: SemanticLabelsSupportFlagsFB) -> bool

Returns whether other is a subset of self