Struct openxr_sys::SpaceLocationFlags
source · [−]#[repr(transparent)]pub struct SpaceLocationFlags(_);Expand description
Implementations
sourceimpl SpaceLocationFlags
impl SpaceLocationFlags
sourcepub const ORIENTATION_VALID: SpaceLocationFlags = _
pub const ORIENTATION_VALID: SpaceLocationFlags = _
Indicates that the orientation member contains valid data
sourcepub const POSITION_VALID: SpaceLocationFlags = _
pub const POSITION_VALID: SpaceLocationFlags = _
Indicates that the position member contains valid data
sourcepub const ORIENTATION_TRACKED: SpaceLocationFlags = _
pub const ORIENTATION_TRACKED: SpaceLocationFlags = _
Indicates whether pose member contains an actively tracked orientation
sourcepub const POSITION_TRACKED: SpaceLocationFlags = _
pub const POSITION_TRACKED: SpaceLocationFlags = _
Indicates whether pose member contains an actively tracked position
sourceimpl SpaceLocationFlags
impl SpaceLocationFlags
pub const EMPTY: Self = _
pub fn from_raw(x: u64) -> Self
pub fn into_raw(self) -> u64
pub fn is_empty(self) -> bool
pub fn intersects(self, other: SpaceLocationFlags) -> bool
sourcepub fn contains(self, other: SpaceLocationFlags) -> bool
pub fn contains(self, other: SpaceLocationFlags) -> bool
Returns whether other is a subset of self