#[repr(transparent)]
pub struct SwapchainUsageFlags(_);
Implementations

Specifies that the image may: be a color rendering target.

Specifies that the image may: be a depth/stencil rendering target.

Specifies that the image may: be accessed out of order and that access may: be via atomic operations.

Specifies that the image may: be used as the source of a transfer operation.

Specifies that the image may: be used as the destination of a transfer operation.

Specifies that the image may: be sampled by a shader.

Specifies that the image may: be reinterpreted as another image format.

Specifies that the image may: be used as a input attachment.

Returns whether other is a subset of self