Struct openxr_sys::FacialTrackingTypeHTC
source · [−]#[repr(transparent)]pub struct FacialTrackingTypeHTC(_);Expand description
Implementations
sourceimpl FacialTrackingTypeHTC
impl FacialTrackingTypeHTC
sourcepub const EYE_DEFAULT: FacialTrackingTypeHTC = _
pub const EYE_DEFAULT: FacialTrackingTypeHTC = _
Specifies this handle will observe eye expressions, with values indexed by XrEyeExpressionHTC whose count is XR_FACIAL_EXPRESSION_EYE_COUNT_HTC.
sourcepub const LIP_DEFAULT: FacialTrackingTypeHTC = _
pub const LIP_DEFAULT: FacialTrackingTypeHTC = _
Specifies this handle will observe lip expressions, with values indexed by XrLipExpressionHTC whose count is XR_FACIAL_EXPRESSION_LIP_COUNT_HTC.
pub fn from_raw(x: i32) -> Self
pub fn into_raw(self) -> i32