#[repr(transparent)]pub struct PerfSettingsNotificationLevelEXT(_);Expand description
Implementations
sourceimpl PerfSettingsNotificationLevelEXT
impl PerfSettingsNotificationLevelEXT
sourcepub const NORMAL: PerfSettingsNotificationLevelEXT = _
pub const NORMAL: PerfSettingsNotificationLevelEXT = _
Notifies that the sub-domain has reached a level where no further actions other than currently applied are necessary
sourcepub const WARNING: PerfSettingsNotificationLevelEXT = _
pub const WARNING: PerfSettingsNotificationLevelEXT = _
Notifies that the sub-domain has reached an early warning level where the application should start proactive mitigation actions with the goal to return to the XR_PERF_NOTIF_LEVEL_NORMAL level
sourcepub const IMPAIRED: PerfSettingsNotificationLevelEXT = _
pub const IMPAIRED: PerfSettingsNotificationLevelEXT = _
Notifies that the sub-domain has reached a critical level with significant performance degradation. The application should take drastic mitigation action
pub fn from_raw(x: i32) -> Self
pub fn into_raw(self) -> i32