Struct openxr_sys::SwapchainUsageFlags
source · [−]#[repr(transparent)]pub struct SwapchainUsageFlags(_);Expand description
Implementations
sourceimpl SwapchainUsageFlags
impl SwapchainUsageFlags
sourcepub const COLOR_ATTACHMENT: SwapchainUsageFlags = _
pub const COLOR_ATTACHMENT: SwapchainUsageFlags = _
Specifies that the image may: be a color rendering target.
sourcepub const DEPTH_STENCIL_ATTACHMENT: SwapchainUsageFlags = _
pub const DEPTH_STENCIL_ATTACHMENT: SwapchainUsageFlags = _
Specifies that the image may: be a depth/stencil rendering target.
sourcepub const UNORDERED_ACCESS: SwapchainUsageFlags = _
pub const UNORDERED_ACCESS: SwapchainUsageFlags = _
Specifies that the image may: be accessed out of order and that access may: be via atomic operations.
sourcepub const TRANSFER_SRC: SwapchainUsageFlags = _
pub const TRANSFER_SRC: SwapchainUsageFlags = _
Specifies that the image may: be used as the source of a transfer operation.
sourcepub const TRANSFER_DST: SwapchainUsageFlags = _
pub const TRANSFER_DST: SwapchainUsageFlags = _
Specifies that the image may: be used as the destination of a transfer operation.
sourcepub const SAMPLED: SwapchainUsageFlags = _
pub const SAMPLED: SwapchainUsageFlags = _
Specifies that the image may: be sampled by a shader.
sourcepub const MUTABLE_FORMAT: SwapchainUsageFlags = _
pub const MUTABLE_FORMAT: SwapchainUsageFlags = _
Specifies that the image may: be reinterpreted as another image format.
sourcepub const INPUT_ATTACHMENT: SwapchainUsageFlags = _
pub const INPUT_ATTACHMENT: SwapchainUsageFlags = _
Specifies that the image may: be used as a input attachment.
sourceimpl SwapchainUsageFlags
impl SwapchainUsageFlags
pub const EMPTY: Self = _
pub fn from_raw(x: u64) -> Self
pub fn into_raw(self) -> u64
pub fn is_empty(self) -> bool
pub fn intersects(self, other: SwapchainUsageFlags) -> bool
sourcepub fn contains(self, other: SwapchainUsageFlags) -> bool
pub fn contains(self, other: SwapchainUsageFlags) -> bool
Returns whether other is a subset of self